# mytestpkg

Test publishing on PyPI

## Installation

```bash
$ pip install mytestpkg
```

## Usage

- TODO

## Contributing

Interested in contributing? Check out the contributing guidelines. Please note that this project is released with a Code of Conduct. By contributing to this project, you agree to abide by its terms.

## License

`mytestpkg` was created by Frank Cao. It is licensed under the terms of the MIT license.

## Credits

`mytestpkg` was created with [`cookiecutter`](https://cookiecutter.readthedocs.io/en/latest/) and the `py-pkgs-cookiecutter` [template](https://github.com/py-pkgs/py-pkgs-cookiecutter).
